GENCCODE_ASSEMBLY_TYPE=
SO=dll
SOBJ=dll
A=lib
LIBPREFIX=
LIB_EXT_ORDER=68.dll
COMPILE=cl.exe   -DHAVE_DLOPEN=0 -DU_HAVE_MMAP=0 -DU_HAVE_DIRENT_H=0 -DU_HAVE_POPEN=0 -DU_HAVE_TZNAME=0 -DU_HAVE_STRTOD_L=0  -DWINVER=0x0601 -D_WIN32_WINNT=0x0601 -DU_RELEASE=1 -D_CRT_SECURE_NO_DEPRECATE -DU_ATTRIBUTE_DEPRECATED= -DWIN32 -DCYGWINMSVC   -GF -nologo -utf-8 -c
LIBFLAGS=-I/c/ci/icu_1611675603537/_h_env/Library/include  
GENLIB=LINK.EXE -DLL  -nologo
LDICUDTFLAGS=-NOENTRY
LD_SONAME=-IMPLIB:
RPATH_FLAGS=
BIR_LDFLAGS=
AR=LIB.EXE
ARFLAGS=-nologo
RANLIB=ls -s
INSTALL_CMD=/usr/bin/install -c
